//****************************************************************************
//  @DOC EXTERNE
//
//  @MODULE       Msg.cpp
//
//  @DESCRIPTION  Implmentation de la classe <c Msg>.<nl>
//	   
//  @AUTEUR       (c) V. Osele (osele@mygale.org)       Mai 1998
//
//  @COM          Prvenez moi, si vous faites des modifications.
//
//****************************************************************************

#include "Msg.h"

//****************************************************************************
//
//  @METHODE       StringExtract
//
//  @DESCRIPTION   Dcoupe une chaine en debut/milieu/fin selon 2 chaines de
//                 test.
//
//  @COM           'from' peut etre equivalent a 'apres', dans ce cas from est
//                 ecras.<nl>
//                 Le 2me dlimitaeur 'end' peut tre vide, la chaine est
//                 dcoup en deux partie, result est  vide.
//
//  @PARAMETRE     chaine de base
//  @PARAMETRE     1er dlimitateur (dlimitaeur de dbut)
//  @PARAMETRE     2eme dlimitaeur (dlimitateur de fin)
//  @PARAMETRE     partie de la chaine de base avant le 1er dlimitateur
//  @PARAMETRE     partie de la chaine de base entre les dlimitateurs
//  @PARAMETRE     partie de la chaine de base aprs le 2eme dlimitateur
//
//  @RETOUR        faux si les dlimitaeurs dfinis n'ont pas t
//                 trouvs.<nl>
//                 vrai sinon.
//
//  @EXEMPLE       Dcoupage d'un tableau html |
//
//  if (StringExtract(line,"<TD>","</TD>",avant,min,line)) {
//    ...
//  }
//
//****************************************************************************
bool Msg::StringExtract(CString &from,LPCTSTR start,LPCTSTR end,
						  CString &avant,CString &result,CString &apres)
{
	result.Empty();
	// recherche de la squence de dbut
	int index=from.Find(start);
	if (index<0) {
		avant.Empty();
		apres=from;
		return false; // pas trouve
	}
	// on enleve la sequence de debut
	avant=from.Left(index);
	apres=from.Mid(index+strlen(start));
	// recherche que sur start ?
	if (strlen(end)==0) return true;
	// on recherche la fin
	index=apres.Find(end);
	if (index<0) {
		return false;
	}
	// on a trouv, on coupe
	result=apres.Mid(0,index);
	apres=apres.Mid(index+strlen(end));
	return true;
}

//****************************************************************************
//
//  @METHODE       StringHtmlToText
//
//  @DESCRIPTION   Convertie une chaine HTML en chaine texte simple
//
//  @COM           'from' ne peut etre equivalent a 'result'.<nl>
//                 Seul le jeux de caractres est traduit, les tags restent.
//
//  @TODO          Enlever les tags HTML.<nl>
//                 Implmenter la traduction des &#...;
//
//  @PARAMETRE     chaine de base
//  @PARAMETRE     rsultat
//
//  @RETOUR        toujours vrai pour le moment
//
//  @EXEMPLE       Transformation d'une chaine html |
//
//  CString line="test d'accent &eaccute;";
//  CString Result;
//
//  StringHtmlToText(CString &from,CString &result);
//  // donne  test d'accent e
//
//****************************************************************************
bool Msg::StringHtmlToText(CString &from,CString &result)
{
	result.Empty();
	// recherche de &eacute;
	bool transfert=true;
	for (int i=0; i<from.GetLength(); i++) {
		if (from[i]=='&') {
			transfert=false;
			CString temp=from.Mid(i,5);
			if (temp.Find("&amp")==0) result+='&';
			else if (strchr("aeiouyc",temp[1])!=NULL) result+=from[i+1];
/*
			else if (from[i+1]==#)
				result+=from[i+1];
*/
			else if (temp.Find("&quot")==0) result+='"';
			else if (temp.Find("&lt")==0) result+='<';
			else if (temp.Find("&gt")==0) result+='>';
			else if (temp.Find("&nbsp")==0) result+=' ';
			continue;
		}
		if ((from[i]==';') && (!transfert)) {
			transfert=true;
			continue;
		}
		if (transfert)
			result+=from[i]; 
	}
	return true;
}
